"use strict";

var Site = {};
Site.primaryColor = '#EC008C';
Site.darkColor = '#000D42';
Site.headerHeightSticky = 48;
Site.headerHeightStickyWithBanner = 110;
Site.headerHeightStickyWithBannerMobile = 100;
Site.setCookie = function (cname, cvalue, exdays) {
  var d = new Date();
  d.setTime(d.getTime() + exdays * 24 * 60 * 60 * 1000);
  var expires = 'expires=' + d.toUTCString();
  document.cookie = cname + '=' + cvalue + ';' + expires + ';path=/';
};

Site.getCookie = function (cname) {
  var name = cname + '=';
  var decodedCookie = decodeURIComponent(document.cookie);
  var ca = decodedCookie.split(';');
  for (var i = 0; i < ca.length; i++) {
    var c = ca[i];
    while (' ' === c.charAt(0)) {
      c = c.substring(1);
    }
    if (0 === c.indexOf(name)) {
      return c.substring(name.length, c.length);
    }
  }
  return '';
};


Site.windowSize = 'sm';
Site.getUriWithParam = function (baseUrl, params) {
  var Url = new URL(baseUrl);
  var urlParams = new URLSearchParams(Url.search);
  for (var key in params) {
    if (params[key] !== undefined) {
      urlParams.set(key, params[key]);
    }
  }
  Url.search = urlParams.toString();
  return Url.toString();
};

Site.getUriParam = function (baseUrl, params) {
  var Url = new URL(baseUrl);
  var urlParams = new URLSearchParams(Url.search);
  for (var key in params) {
    if (params[key] !== undefined) {
      urlParams.set(key, params[key]);
    }
  }


  return urlParams.toString();
};


Site.setViewPort = function () {
  var vh = window.innerHeight * 0.01;
  document.documentElement.style.setProperty('--vh', "".concat(vh, "px"));
};


Site.setWindowSize = function () {
  Site.windowSize = 'sm';
  if (1200 <= window.innerWidth) {
    Site.windowSize = 'xl';
  } else if (1024 <= window.innerWidth) {
    Site.windowSize = 'lg';
  } else if (768 <= window.innerWidth) {
    Site.windowSize = 'md';
  } else if (375 <= window.innerWidth) {
    Site.windowSize = 'sm';
  }
  Site.setViewPort();
};


Site.getWindowScroll = function () {
  var doc = document.documentElement;
  var left = (window.pageXOffset || doc.scrollLeft) - (doc.clientLeft || 0);
  var top = (window.pageYOffset || doc.scrollTop) - (doc.clientTop || 0);
  return {
    left: left,
    top: top
  };
};


Site.scrollTo = function (hash) {
  var offset = Site.headerHeightSticky;
  var header = jQuery('#color-band-header');
  var $section = jQuery(hash);
  if (header.hasClass('with-subheader')) {
    offset = Site.headerHeightStickyWithBannerMobile;
    if (1024 <= window.innerWidth) {
      offset = Site.headerHeightStickyWithBanner;
    }
  }

  console.log('offset', offset);
  if (0 < $section.length) {
    jQuery('html, body').animate({
      scrollTop: $section.offset().top - offset
    }, 900);
  }
};

Site.scrollToEl = function (el) {
  var time = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 900;
  var offset = Site.headerHeightSticky;
  var header = jQuery('#color-band-header');
  var section = jQuery(el);
  if (header.hasClass('with-subheader')) {
    offset = Site.headerHeightStickyWithBannerMobile;

    if (1024 <= window.innerWidth) {
      offset = Site.headerHeightStickyWithBanner;
    }
  }

  if (0 < section.length) {
    jQuery('html, body').animate({
      scrollTop: section.offset().top - offset
    }, time);
  }
};

Site.cloudworxIframeResize = function () {
  if (0 < jQuery('.cloudworx-iframe').length) {
    jQuery('.cloudworx-iframe').iFrameResize();
  }
};


Site.inlineSVG = function () {
  jQuery('[data-inline-svg]').inlineSvg();
  jQuery('[data-inline-svg]').on('svgInlined', function (e, svgElement) {
  });
};


Site.menuFooterMobile = function () {
  jQuery('.collapse-menu-footer').on('shown.bs.collapse', function () {
    jQuery(this).closest('.row').addClass('active');
  });
  jQuery('.collapse-menu-footer').on('hidden.bs.collapse', function () {
    var hasShow = jQuery(this).closest('.row').find('.collapse-menu-footer.show');
    if (0 === hasShow.length) {
      jQuery(this).closest('.row').removeClass('active');
    }
  });
};

jQuery(function () {
  (function () {
    Site.setWindowSize();
    Site.inlineSVG();
    Site.cloudworxIframeResize();
    Site.menuFooterMobile();
    jQuery(window).on('resize', function () {
      Site.setWindowSize();
      Site.cloudworxIframeResize();
    });
  })();
});
"use strict";

var bannerCloseVar = 'blue_horizon_banner_close';

Site.stickyHeader = function (scrollTop) {
  var header = jQuery('#color-band-header');

  if (50 < scrollTop) {
    header.addClass('sticky');
    jQuery('body').addClass('is-sticky-header');
  } else {
    header.removeClass('sticky');
    jQuery('body').removeClass('is-sticky-header');
  }
};

Site.menuOverlayClose = function () {
  var $menuToggle = jQuery('.toggle-menu-overlay');

  if ($menuToggle.hasClass('open')) {
    $menuToggle.trigger('click');
  }
};

Site.menuOverlay = function () {
  var $menuOverlay = jQuery('.menu-overlay');

  gsap.set('.hamburger .line02', {
    attr: {
      x2: 20
    }
  });

  var hamburgerMotion = new gsap.timeline()
  .to('.hamburger .line01', 0.4, {
    attr: {
      x1: 5,
      x2: 25,
      y1: 5,
      y2: 25
    },
    ease: Linear.easeInOut
  }, 0).to('.hamburger .line02', 0.4, {
    attr: {
      x1: 5,
      x2: 25,
      y1: 25,
      y2: 5
    },
    ease: Linear.easeInOut
  }, 0).reverse();

  jQuery('.toggle-menu-overlay').on('click', function (e) {
    e.preventDefault();
    e.stopPropagation();
    jQuery(this).toggleClass('open');
    $menuOverlay.toggleClass('open');
    hamburgerMotion.reversed(!hamburgerMotion.reversed());
    jQuery('html').toggleClass('menu-overlay-open');
  });
  jQuery('.menu-overlay').on('click', 'a', function () {
    Site.menuOverlayClose();
  });
  jQuery('.menu-overlay').on('click', '.menu-layer-overlay', function () {
    Site.menuOverlayClose();
  });
  jQuery('.menu-overlay').on('click', '.menu-overlay-close', function (e) {
    e.preventDefault();
    e.stopPropagation();
    Site.menuOverlayClose();
  });
};

Site.headerBanner = function () {
  jQuery('.header-banner-close').on('click', function (e) {
    e.stopPropagation();
    e.preventDefault();
    jQuery(this).closest('.header-banner').addClass('banner-close');
    jQuery('html').toggleClass('header-banner-close');
    jQuery('body').removeClass('with-header-banner');

    Site.setCookie(bannerCloseVar, 'true', 30);
    jQuery(this).closest('.header-banner').trigger('banner-close');
  });
};

jQuery(function () {
  (function () {
    Site.stickyHeader(Site.getWindowScroll().top);
    Site.menuOverlay();
    Site.headerBanner();
    jQuery(window).on('scroll', function () {
      Site.stickyHeader(Site.getWindowScroll().top);
    });
    jQuery(window).on('resize', function () {
      Site.menuOverlayClose();
    });
  })();
});
"use strict";

var videos = function videos() {
  jQuery('.video-js').each(function (index, el) {
    var player = videojs(el, {
      controls: true,
      autoplay: false,
      fluid: true,
      preload: 'auto',
      techOrder: ['vimeo', 'youtube', 'html5'],
      bigPlayButton: true,
      youtube: {
        ytControls: 0,
        customVars: {
          wmode: 'transparent'
        }
      }
    });

    player.on('ended', function () {
      player.pause();
      player.currentTime(0);
      player.hasStarted(false);
    });
  });
};

jQuery(function () {
  (function () {
    videos();
  })();
});
"use strict";

/* eslint-disable vars-on-top */

var markers = false;
var tilesImagesSizes = function tilesImagesSizes(el, img) {
  var offset = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  var tiles = jQuery(el).closest('.tiles-gsap');
  var div = tiles.find('> div:first-child');
  var divH = div.height();
  var divW = div.width();
  var divs = tiles.find('> div');
  var containerWidth = window.screen.width / 2;
  var containerHeight = jQuery(el).height();
  var ratio = img.width / (containerWidth - offset);
  var imageDisplayH = img.height / ratio;
  var imageDisplayW = img.width / ratio;
  var offsetH = (containerHeight - imageDisplayH) / 2;
  var offsetW = (containerWidth - imageDisplayW) / 2;
  return {
    containerWidth: containerWidth,
    containerHeight: containerHeight,
    ratio: ratio,
    imageDisplayH: imageDisplayH,
    imageDisplayW: imageDisplayW,
    offsetH: offsetH,
    offsetW: offsetW,
    tiles: tiles,
    div: div,
    divH: divH,
    divW: divW,
    divs: divs
  };
};

var tilesImageLeft = function tilesImageLeft(el, imageSrc) {
  var className = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  var img = new Image();
  img.onload = function () {
    var _tilesImagesSizes = tilesImagesSizes(el, this),
        imageDisplayH = _tilesImagesSizes.imageDisplayH,
        offsetH = _tilesImagesSizes.offsetH,
        offsetW = _tilesImagesSizes.offsetW,
        divH = _tilesImagesSizes.divH,
        divW = _tilesImagesSizes.divW,
        divs = _tilesImagesSizes.divs;

    var count = 1;
    var row = 1;
    divs.each(function () {
      if (6 < count) {
        count = 1;
        row++;
      }

      if (3 >= count) {
        var varX = (count - 1) * divW * -1;
        var varY = (row - 1) * divH * -1;

        if (!className) {
          jQuery(this).css({
            backgroundPosition: "".concat(varX + offsetW, "px ").concat(varY, "px"),
            backgroundSize: "".concat(imageDisplayH, "px auto")
          });
        } else {
          jQuery(this).find(className).css({
            backgroundPosition: "".concat(varX + offsetW, "px ").concat(varY, "px"),
            backgroundSize: "".concat(imageDisplayH, "px auto")
          });
        }
      }
      count++;
    });
  };

  img.src = imageSrc;
};

var tilesImageRight = function tilesImageRight(el, imageSrc) {
  var className = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  var img = new Image();
  img.onload = function () {
    var _tilesImagesSizes2 = tilesImagesSizes(el, this),
        imageDisplayH = _tilesImagesSizes2.imageDisplayH,
        offsetH = _tilesImagesSizes2.offsetH,
        offsetW = _tilesImagesSizes2.offsetW,
        divH = _tilesImagesSizes2.divH,
        divW = _tilesImagesSizes2.divW,
        divs = _tilesImagesSizes2.divs;

    var count = 1;
    var row = 1;
    divs.each(function () {
      if (6 < count) {
        count = 1;
        row++;
      }

      if (3 < count) {
        var varX = (count - 4) * divW * -1;
        var varY = (row - 1) * divH * -1;
        if (!className) {
          jQuery(this).css({
            backgroundPosition: "".concat(varX + offsetW, "px ").concat(varY, "px"),
            backgroundSize: "".concat(imageDisplayH, "px auto")
          });
        } else {
          jQuery(this).find(className).css({
            backgroundPosition: "".concat(varX + offsetW, "px ").concat(varY, "px"),
            backgroundSize: "".concat(imageDisplayH, "px auto")
          });
        }
      }
      count++;
    });
  };

  img.src = imageSrc;
};

var tilesImageArrow = function tilesImageArrow(el) {
  var data = jQuery(el).data();
  var img = new Image();
  img.onload = function () {
    var _tilesImagesSizes3 = tilesImagesSizes(el, this, 80),
        imageDisplayH = _tilesImagesSizes3.imageDisplayH,
        offsetH = _tilesImagesSizes3.offsetH,
        divH = _tilesImagesSizes3.divH,
        divW = _tilesImagesSizes3.divW,
        divs = _tilesImagesSizes3.divs;

    var count = 1;
    var row = 1;
    divs.each(function () {
      if (6 < count) {
        count = 1;
        row++;
      }
      if (3 < count) {
        var varX = (count - 4) * divW * -1;
        var varY = (row - 1) * divH * -1;
        jQuery(this).find('.tile-back').css({
          backgroundPosition: "".concat(varX, "px ").concat(varY + offsetH * 2, "px"),
          backgroundSize: "".concat(imageDisplayH, "px auto")
        });
      }
      count++;
    });
  };

  img.src = data.image;
};

var resizeTilesBg = function resizeTilesBg() {
  jQuery('.tiles-image-left').each(function () {
    var image = jQuery(this).data().image;
    tilesImageLeft(this, image);
  });
  jQuery('.tiles-image-right').each(function () {
    var image = jQuery(this).data().image;
    tilesImageRight(this, image);
  });
  jQuery('.tiles-image-left-right').each(function () {
    var image = jQuery(this).data().image;
    var image2 = jQuery(this).data().image2;
    tilesImageLeft(this, image, '.tile-front');
    tilesImageRight(this, image2, '.tile-back');
  });
  jQuery('.tiles-arrows').each(function () {
    tilesImageArrow(this);
  });
};

var tilesBg = function tilesBg() {
  resizeTilesBg();

  var banner = jQuery('.header-banner');
  banner.on('banner-close', function () {
    resizeTilesBg();
  });
  jQuery(window).on('resize', function () {
    setTimeout(function () {
      resizeTilesBg();
    }, 300);
  });
};

var tilesHero = function tilesHero() {
  var wrapper = jQuery('.section-hero-pin-wrapper');

  if (0 == wrapper.length) {
    return null;
  }
  var tiles = wrapper.find('.tiles-gsap').find('> div');
  var _start = '1px';
  var header = jQuery('#color-band-header');
  var banner = jQuery('.header-banner');

  if (0 < banner.length && !banner.hasClass('banner-close')) {
    _start = "-".concat(banner.height() - 1, "px");
  }

  var hero = wrapper.find('.section-hero');
  var titleHero1 = hero.find('.primary-title h1');
  var titleHero2 = hero.find('.secondary-title h1');
  var bodyHero = hero.find('.body-text-content'); // Arrows
  var arrows = wrapper.find('.section-arrows');
  var titleArrow = arrows.find('.section-caption-title');
  var bodyArrow = arrows.find('.section-caption-body'); 
  var tlHero = gsap.timeline();
  var countStagger = 0;
  tlHero.fromTo(titleHero1.get(0), {
    x: 0,
    y: 0,
    autoAlpha: 1
  }, {
    duration: 0.3,
    x: 0,
    y: 0,
    autoAlpha: 0
  }).fromTo(titleHero2.get(0), {
    x: 0,
    y: 0,
    autoAlpha: 1
  }, {
    duration: 0.3,
    x: 0,
    y: 0,
    autoAlpha: 0
  }).fromTo(bodyHero.get(0), {
    x: 0,
    y: 0,
    autoAlpha: 1
  }, {
    duration: 0.5,
    x: 0,
    y: 0,
    autoAlpha: 0
  }) 
  .fromTo(tiles.toArray(), {
    rotationY: 0
  }, {
    rotationY: -180,
    // duration: 0.6,
    stagger: {
      grid: [6, 6],
      from: 0,
      amount: 1.5,
      onComplete: function onComplete() {
        if (36 <= countStagger) {
          countStagger = 0;
        }

        countStagger++;

        if (4 <= countStagger) {
          header.addClass('header-dark');
        }
      },
      onReverseComplete: function onReverseComplete() {
        if (36 <= countStagger) {
          countStagger = 0;
        }

        countStagger++;

        if (4 <= countStagger) {
          header.removeClass('header-dark');
        }
      }
    }
  })
  .fromTo(titleArrow.get(0), {
    x: 0,
    y: 0,
    autoAlpha: 0
  }, {
    duration: 0.5,
    x: 0,
    y: 0,
    autoAlpha: 1
  }).fromTo(bodyArrow.get(0), {
    x: 0,
    y: 0,
    autoAlpha: 0
  }, {
    duration: 0.5,
    x: 0,
    y: 0,
    autoAlpha: 1
  }).eventCallback('onStart', function () {
    jQuery(document.documentElement).addClass('overflow-hidden');
  }).eventCallback('onComplete', function () {
    jQuery(document.documentElement).removeClass('overflow-hidden');
  }).eventCallback('onReverseComplete', function () {
    jQuery(document.documentElement).removeClass('overflow-hidden');
  }).pause(); // Scroll Trigger

  var scrollTrigger = ScrollTrigger.create({
    trigger: wrapper.closest('.elementor-element').get(0),
    start: function start() {
      return _start;
    },
    end: '+=25%',
    pin: true,
    scrub: 0,
    pinSpacing: true,
    markers: markers,
    onEnter: function onEnter() {
      tlHero.play();
    },
    onEnterBack: function onEnterBack() {
      Site.scrollToEl(wrapper.get(0), 0);
    },
    onLeaveBack: function onLeaveBack() {
      Site.stickyHeader(0);

      Site.scrollToEl(wrapper.get(0), 0);
      tlHero.reverse();
    },
    onLeave: function onLeave() {
      jQuery(document.documentElement).removeClass('overflow-hidden');
      Site.stickyHeader(60);
    }
  }); // Banner Close

  banner.on('banner-close', function () {
    scrollTrigger.kill();
    tilesHero();
  });
};


var tilesFeatures = function tilesFeatures() {
  var wrapper = jQuery('.section-feature-tiles');

  if (0 == wrapper.length) {
    return null;
  }

  var tiles = wrapper.find('.tiles-gsap').find('> div');

  var section1 = wrapper.find('.section-gamer-changers');
  var title1 = section1.find('.section-caption-title');
  var body1 = section1.find('.section-caption-body');
  var arrow1 = section1.find('.tile-arrow');
  var section2 = wrapper.find('.section-tipping-point');
  var title2 = section2.find('.section-caption-title');
  var body2 = section2.find('.section-caption-body');
  var arrow2 = section2.find('.tile-arrow');

  var timeline = gsap.timeline({});
  timeline.fromTo(title1.get(0), {
    x: 0,
    y: 0,
    autoAlpha: 1
  }, {
    duration: 0.3,
    x: 0,
    y: 0,
    autoAlpha: 0
  }).fromTo(body1.get(0), {
    x: 0,
    y: 0,
    autoAlpha: 1
  }, {
    duration: 0.3,
    x: 0,
    y: 0,
    autoAlpha: 0
  }).fromTo(arrow1.get(0), {
    x: 0,
    y: 0,
    autoAlpha: 1
  }, {
    duration: 0.5,
    x: 0,
    y: 0,
    autoAlpha: 0
  }).fromTo(tiles.toArray(), {
    rotationY: 0
  }, {
    rotationY: -180,
    stagger: {
      grid: [6, 6],
      from: 0,
      amount: 1.5
    }
  }).fromTo(title2.get(0), {
    x: 0,
    y: 0,
    autoAlpha: 0
  }, {
    duration: 0.5,
    x: 0,
    y: 0,
    autoAlpha: 1
  }).fromTo(body2.get(0), {
    x: 0,
    y: 0,
    autoAlpha: 0
  }, {
    duration: 0.5,
    x: 0,
    y: 0,
    autoAlpha: 1
  }).fromTo(arrow2.get(0), {
    x: 0,
    y: 0,
    autoAlpha: 0
  }, {
    duration: 0.5,
    x: 0,
    y: 0,
    autoAlpha: 1
  }).eventCallback('onStart', function () {
    jQuery(document.documentElement).addClass('overflow-hidden');
  }).eventCallback('onReverse', function () {
  }).eventCallback('onComplete', function () {
    jQuery(document.documentElement).removeClass('overflow-hidden');
  }).eventCallback('onReverseComplete', function () {
    jQuery(document.documentElement).removeClass('overflow-hidden');
  }).pause();
  ScrollTrigger.create({
    trigger: wrapper.closest('.elementor-element').get(0),
    start: '=-47px',
    end: '+=100%',
    pin: true,
    scrub: 0,
    pinSpacing: true,
    markers: markers,
    onEnter: function onEnter() {
    },
    onUpdate: function onUpdate(e) {
      if (0.8 <= e.progress) {
        timeline.play();
      }
    },
    onEnterBack: function onEnterBack() {
      Site.scrollToEl(wrapper.get(0), 0);
    },
    onLeaveBack: function onLeaveBack() {
      Site.scrollToEl(wrapper.get(0), 0);
      jQuery(document.documentElement).addClass('overflow-hidden');
      timeline.reverse();
    },
    onLeave: function onLeave() {
      jQuery(document.documentElement).removeClass('overflow-hidden');
    }
  });
};

jQuery(function () {
  (function () {
  })();
});
"use strict";

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
var carousel = function carousel() {
  jQuery('.carousel-block ').each(function () {
    var carousel = jQuery(this);
    var wrapper = carousel.closest('.carousel-block-wrapper');
    var navigation = wrapper.find('.carousel-block-navigation');
    var navigationPrev = navigation.find('.prev');
    var navigationNext = navigation.find('.next'); //

    function resize(carousel) {
      var triggerResize = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;

      if (carousel.hasClass('c-text')) {
        var someCarouselImage = jQuery('.c-image');

        if (0 < someCarouselImage.length) {
          carousel.css({
            height: "".concat(someCarouselImage.height(), "px")
          });

          if (triggerResize) {
            carousel.slick('resize');
          }
        }
      }
    } // Check if has navigation


    function checkIfHasNavigation(slick) {
      if (slick.slideCount > slick.options.slidesToShow) {
        navigationNext.removeClass('disabled');
        navigation.removeClass('d-none');
      } else {
        navigationNext.addClass('disabled');
        navigationPrev.addClass('disabled');
        navigation.addClass('d-none');
      }
    } // Navigation Flow


    function navigationFlow(slick) {
      if (slick.currentSlide >= slick.slideCount - slick.options.slidesToShow) {
        navigationNext.addClass('disabled');
      } else {
        navigationNext.removeClass('disabled');
      }

      if (0 == slick.currentSlide) {
        navigationPrev.addClass('disabled');
      } else {
        navigationPrev.removeClass('disabled');
      }
    }

    carousel.on('init', function (event, slick) {
      checkIfHasNavigation(slick);
      navigationFlow(slick);
      resize(carousel, false);
    });
    console.log(carousel);
    carousel.slick({
      infinite: false,
      arrows: false,
      dots: false,
      autoplay: false,
      speed: 900,
      rows: 0,
      slidesToShow: 1,
      variableWidth: carousel.hasClass('c-text-md')
    });
    carousel.on('afterChange', function (event, slick) {
      navigationFlow(slick);
    });

    navigationPrev.on('click', function (e) {
      e.stopPropagation();
      e.preventDefault();
      carousel.slick('slickPrev');
    });
    navigationNext.on('click', function (e) {
      e.stopPropagation();
      e.preventDefault();
      carousel.slick('slickNext');
    });
    jQuery(window).on('resize', function () {
      resize(carousel);
    });
  });
};

jQuery(function () {
  (function () {
    carousel();
  })();
});


"use strict";

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
var contactCollapse = function contactCollapse() {
  jQuery('.section-contact ').each(function () {
    var items = jQuery(this).find('.contact-item');
    jQuery(this).on('click', '.btn', function (e) {
      e.stopPropagation();
      e.preventDefault();
      items.hide();
      var href = jQuery(this).attr('href');
      jQuery(href).show();
      setTimeout(function () {
        Site.scrollToEl(href, 0);
      });
    });
  });
};

jQuery(function () {
  (function () {
    var element = jQuery('.section-contact');
    if (1 > element.length) {
      return;
    }
    contactCollapse();
  })();
});
"use strict";

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
var carouselImpact = function carouselImpact(element) {
  var carousel = element.find('.carousel-impact');
  var navigation = element.find('.carousel-impact-navigation');
  var navigationPrev = navigation.find('.prev');
  var navigationNext = navigation.find('.next');

  function checkIfHasNavigation(slick) {
    if (slick.slideCount > slick.options.slidesToShow) {
      navigationNext.removeClass('disabled');
      navigation.removeClass('d-none');
    } else {
      navigationNext.addClass('disabled');
      navigationPrev.addClass('disabled');
      navigation.addClass('d-none');
    }
  } // Navigation Flow


  function navigationFlow(slick) {
    if (slick.currentSlide >= slick.slideCount - slick.options.slidesToShow) {
      navigationNext.addClass('disabled');
    } else {
      navigationNext.removeClass('disabled');
    }
    if (0 == slick.currentSlide) {
      navigationPrev.addClass('disabled');
    } else {
      navigationPrev.removeClass('disabled');
    }
  }

  carousel.on('init', function (event, slick) {
    checkIfHasNavigation(slick);
    navigationFlow(slick);
  });
  carousel.slick({
    centerMode: false,
    infinite: false,
    arrows: false,
    draggable: false,
    dots: false,
    autoplay: false,
    speed: 900,
    rows: 0,
    slidesToShow:3,
    slidesToScroll:1,
    responsive: [{
      breakpoint: 600,
      settings: {
        slidesToShow: 2,
        draggable: true,
        arrows: true,
      }
    }, {
      breakpoint: 480,
      settings: {
        slidesToShow: 1,
        draggable: true,
        arrows: true,
      }
    }]
  });
  carousel.on('afterChange', function (event, slick) {
    navigationFlow(slick);
  }); // Navigation

  navigationPrev.on('click', function (e) {
    e.stopPropagation();
    e.preventDefault();
    carousel.slick('slickPrev');
  });
  navigationNext.on('click', function (e) {
    e.stopPropagation();
    e.preventDefault();
    carousel.slick('slickNext');
  });
};

jQuery(function () {
  (function () {
    var element = jQuery('.section-impact');
    if (1 > element.length) {
      return;
    }
    carouselImpact(element);
  })();
});
"use strict";

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
var jobs = function jobs() {
  jQuery('.section-jobs').each(function () {
    var section = jQuery(this);
    var modalId = section.data().modalId;
    var modal = new bootstrap.Modal(document.getElementById(modalId), {
      backdrop: true,
      focus: true
    });
    section.find('.job-item').on('click', 'a', function () {
      var modalEl = jQuery(modal._element); // Item
      var item = jQuery(this).closest('.job-item');
      var data = item.data(); // Info
      modalEl.find('.modal-title').text(data.jobTitle);
      modalEl.find('.modal-body-content').html(item.find('.the-content').html()); // Show
      modal.show();
    });
  });
};

jQuery(function () {
  (function () {
    var wrapper = jQuery('.section-jobs');
    if (0 == wrapper.length) {
      return null;
    }

    jobs();
  })();
});


"use strict";

/* eslint-disable no-undef */
var portfolioPopover = function portfolioPopover() {
  jQuery('[data-toggle="popover-portfolio"]').each(function () {
    var data = jQuery(this).data();
    var is_touch_device = 'ontouchstart' in window || window.DocumentTouch && document instanceof DocumentTouch;
    var popover = bootstrap.Popover.getOrCreateInstance(this, {
      trigger: is_touch_device ? 'manual' : 'focus',
      html: true,
      animation: true,
      placement: 'bottom',
      template: '<div class="popover fade popover-portfolio"><div class="popover-arrow"></div><p class="h7 popover-header"></h3><div class="popover-body"></div></div>',
      content: function content() {
        var invested = data.portfolioInvested ? "<p class=\"invested\">".concat(data.portfolioInvestedAt, ": ").concat(data.portfolioInvested, "</p>") : '';
        var url = data.portfolioUrl ? "<a class=\"url\" target=\"_BLANK\" href=\"".concat(data.portfolioUrl, "\">Visit their website</a>") : '';
        var html = "\n                <div class=\"portfolio-popup-content\">\n                    <p class=\"body-text\">".concat(data.portfolioBody, "</span>\n                    ").concat(invested, "\n                    ").concat(url, "\n                </div>\n                ");
        return html;
      },
      title: function title() {
        return data.portfolioName;
      }
    });

    if (is_touch_device) {
      popover._element.addEventListener('click', function () {
        jQuery('[data-toggle="popover-portfolio"]').popover('hide');
        jQuery(this).popover('show');
      });
    }

    popover._element.addEventListener('shown.bs.popover', function () {
      jQuery(this).addClass('active');
    });

    popover._element.addEventListener('hidden.bs.popover', function () {
      jQuery(this).removeClass('active'); // do something...
    });
  });
};

var portfolioFlip = function portfolioFlip() {
  var portfolioItems = jQuery('.portfolio-item-flip');

  if (0 < portfolioItems.length) {
    portfolioItems.on('click', function () {
      var item = jQuery(this);

      if (item.hasClass('active')) {
        item.removeClass('active');
        return null;
      }

      portfolioItems.removeClass('active');
      item.addClass('active');
    });
    jQuery(document).on('click', function (event) {
      if (!jQuery(event.target).closest('.portfolio-item-flip').length) {
        portfolioItems.removeClass('active');
      }
    });
  }
};

jQuery(function () {
  (function () {
    portfolioFlip();
  })();
});
"use strict";

/* eslint-disable camelcase */

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
var updatePaginationColumnSearchData = function updatePaginationColumnSearchData(section, data) {
  var sectionData = jQuery(section).data();
  var pagination = jQuery(section).find('.btn-pagination');
  pagination.attr('data-pagination-page', data.paged);
  pagination.data('pagination-page', data.paged);
  pagination.attr('data-pagination-max', data.total_pages);
  pagination.data('pagination-max', data.total_pages);
  var paginationData = pagination.data();

  if (parseInt(paginationData.paginationPage) === parseInt(paginationData.paginationMax)) {
    pagination.addClass('d-none');
  } else {
    pagination.removeClass('d-none');
  } // Next Page

  var nextPage = parseInt(paginationData.paginationPage) + 1; // Update next page
  var nextPageUrl = "/?paged_".concat(sectionData.postsSlug, "=").concat(Math.min(nextPage, paginationData.paginationMax));
  pagination.attr('href', nextPageUrl);
};

var paginationColumnSearch = function paginationColumnSearch(section) {
  var pagination = jQuery(section).find('.btn-pagination');
  if (0 < pagination.length) {
    pagination.on('click', function (e) {
      e.preventDefault();
      e.stopPropagation();
      var paginationData = jQuery(this).data();
      if (paginationData.paginationPage === paginationData.paginationMax) {
        jQuery(this).remove();
      } else {
        var paged = parseInt(paginationData.paginationPage) + 1;
        var postData = makePostData(jQuery(section).data(), null, null, paged); // Update Data Attr
        jQuery(section).data('posts-paged', paged);
        jQuery(section).attr('data-posts-paged', paged); // Get Posts

        getPostsColumnsSearch(postData, section);
      }
    });
  }
}; // Make the post data :p


var makePostData = function makePostData(sectionData, q, filter, page) {
  var postData = {
    action: 'get_ajax_posts',
    link_text: '',
    display: sectionData.postsDisplay,
    template: sectionData.postsTemplate,
    paged: sectionData.postsPaged,
    limit: sectionData.postsPerPage,
    post_type: sectionData.postsPostType,
    filter: sectionData.postsFilter,
    q: sectionData.postsSearch ? sectionData.postsSearch : ''
  }; // Args query params

  var args = {};

  if (null !== q) {
    postData.q = q;
    args["q_".concat(sectionData.postsSlug)] = q;
  }

  if (null !== filter) {
    postData.filter = filter;
    args["category_".concat(sectionData.postsSlug)] = filter;
  }

  if (page) {
    postData.paged = page;
    args["paged_".concat(sectionData.postsSlug)] = page;
  } // Url Arg


  var newUrl = Site.getUriWithParam(window.location.href, args);
  window.history.pushState(args, null, newUrl);
  return postData;
}; // Ajax


var getPostsColumnsSearch = function getPostsColumnsSearch(postData, section) {
  var filtering = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  // console.log( postData );
  jQuery.ajax({
    type: 'POST',
    url: adminUrl,
    dataType: 'json',
    // add data type
    data: postData,
    beforeSend: function beforeSend() {
      if (!filtering) {
        jQuery(section).find('.btn-pagination').addClass('btn-loading');
      } else {
        jQuery(section).find('.btn-pagination').addClass('d-none');
      }
    },
    complete: function complete() {
      if (!filtering) {
        jQuery(section).find('.btn-pagination').removeClass('btn-loading');
      }
    },
    success: function success(response) {
      jQuery(section).find('.total-items').text("".concat(response.posts_totals, " ").concat(1 === response.posts_totals ? 'item' : 'items')); // Page equals 1 means search and we need regenerate all

      if (1 === parseInt(response.paged)) {
        jQuery(section).find('.post-content-dynamic').html(response.posts);
        updatePaginationColumnSearchData(section, response);
      } else {
        jQuery(section).find('.post-content-dynamic').append(response.posts);
        updatePaginationColumnSearchData(section, response);
      }
    },
    error: function error(err) {
      console.log(err);
    }
  });
}; // Main Function


var postColumnsSearch = function postColumnsSearch() {
  jQuery('.section-post-columns').each(function () {
    var section = this;
    var formSearch = jQuery(section).find('.form-search');
    var postsFilter = jQuery(section).find('.posts-filter');
    var delayTimer = null; // Filter Search On Submit

    formSearch.on('submit', function (e) {
      e.preventDefault();
      e.stopPropagation();
      var dataSubmit = jQuery(this).serializeArray();

      if (0 < dataSubmit.length) {
        var q = dataSubmit[0].value;
        jQuery(section).data('posts-search', q);
        jQuery(section).attr('data-posts-search', q);
        var postData = makePostData(jQuery(section).data(), q, null, 1);
        getPostsColumnsSearch(postData, section, true);
      }
    });

    formSearch.find('input').on('keyup', function () {
      var q = jQuery(this).val();
      if (null != delayTimer) {
        clearTimeout(delayTimer);
      }
      delayTimer = setTimeout(function () {
        jQuery(section).data('posts-search', q);
        jQuery(section).attr('data-posts-search', q);
        var postData = makePostData(jQuery(section).data(), q, null, 1);
        getPostsColumnsSearch(postData, section, true);
      }, 150);
    });

    postsFilter.on('click', 'a', function (e) {
      e.preventDefault();
      e.stopPropagation();
      var data = jQuery(this).data();
      var sectionData = jQuery(section).data(); 
      var slug = data.slug && 'all' == data.slug ? sectionData.postsSlug : data.slug;
      var postData = makePostData(sectionData, null, slug, 1);
      jQuery(section).data('posts-filter', slug);
      jQuery(section).attr('data-posts-filter', slug);
      getPostsColumnsSearch(postData, section, true);
      postsFilter.find('a').removeClass('active');
      jQuery(this).addClass('active');
    });
    paginationColumnSearch(section);
  });
};

jQuery(function () {
  (function () {
    var el = jQuery('.section-post-columns');
    if (0 === el.length) {
      return;
    }
    postColumnsSearch();
  })();
});
"use strict";

/* eslint-disable camelcase */

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
var updatePaginationGridData = function updatePaginationGridData(section, data) {
  var sectionData = jQuery(section).data();
  var pagination = jQuery(section).find('.btn-pagination');
  pagination.attr('data-pagination-page', data.paged);
  pagination.data('pagination-page', data.paged);
  var paginationData = pagination.data();

  if (parseInt(paginationData.paginationPage) === parseInt(paginationData.paginationMax)) {
    pagination.remove();
  } else {
    // Next Page
    var nextPage = parseInt(paginationData.paginationPage) + 1; // Update next page

    var nextPageUrl = "/?paged_".concat(sectionData.postsSlug, "=").concat(Math.min(nextPage, paginationData.paginationMax));
    pagination.attr('href', nextPageUrl);
  }
};

var paginationGrid = function paginationGrid(section) {
  var pagination = jQuery(section).find('.btn-pagination');

  if (0 < pagination.length) {
    pagination.on('click', function (e) {
      e.preventDefault();
      e.stopPropagation();
      var paginationData = jQuery(this).data();

      if (paginationData.paginationPage === paginationData.paginationMax) {
        jQuery(this).remove();
      } else {
        var paged = parseInt(paginationData.paginationPage) + 1;
        var postData = makePostDataGrid(jQuery(section).data(), paged); // Update Data Attr

        jQuery(section).data('posts-paged', paged);
        jQuery(section).attr('data-posts-paged', paged); // Get Posts

        getPostsGrid(postData, section);
      }
    });
  }
}; // Make the post data :p


var makePostDataGrid = function makePostDataGrid(sectionData, page) {
  var postData = {
    action: 'get_ajax_posts',
    display: '',
    link_text: sectionData.postsLinkText,
    template: sectionData.postsTemplate,
    paged: sectionData.postsPaged,
    limit: sectionData.postsPerPage,
    post_type: sectionData.postsPostType,
    filter: sectionData.postsSlug,
    q: ''
  }; // Args query params

  var args = {};

  if (page) {
    postData.paged = page;
    args["paged_".concat(sectionData.postsSlug)] = page;
  } // Url Arg


  var newUrl = Site.getUriWithParam(window.location.href, args);
  window.history.pushState(args, null, newUrl);
  return postData;
}; // Ajax


var getPostsGrid = function getPostsGrid(postData, section) {
  jQuery.ajax({
    type: 'POST',
    url: adminUrl,
    dataType: 'json',
    // add data type
    data: postData,
    beforeSend: function beforeSend() {
      jQuery(section).find('.btn-pagination').addClass('btn-loading');
    },
    complete: function complete() {
      jQuery(section).find('.btn-pagination').removeClass('btn-loading');
    },
    success: function success(response) {
      // Append posts
      jQuery(section).find('.post-content-dynamic').append(response.posts);

      updatePaginationGridData(section, response);
    },
    error: function error(err) {
      console.log(err);
    }
  });
}; // Main Function


var postGrid = function postGrid() {
  jQuery('.section-post-grid').each(function () {
    var section = this;
    paginationGrid(section);
  });
};

jQuery(function () {
  (function () {
    var el = jQuery('.section-post-grid');

    if (0 === el.length) {
      return;
    }

    postGrid();
  })();
});
"use strict";

/* eslint-disable no-undef */
var sectionApproach = function sectionApproach() {
  jQuery('.section-approach').each(function () {
    var section = jQuery(this);
    var image = section.find('.approach-img img');
    var text = section.find('.approach-text');

    gsap.set([text.get(0), image.get(0)], {
      autoAlpha: 0
    });

    var showAnimation = function showAnimation(elem) {
      var show = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
      var y1 = show ? '100%' : 0;
      var y2 = show ? 0 : '100%';
      var autoAlpha1 = show ? 0 : 1;
      var autoAlpha2 = show ? 1 : 0;
      gsap.fromTo(elem, {
        y: y1,
        autoAlpha: autoAlpha1
      }, {
        duration: 1.25,
        y: y2,
        autoAlpha: autoAlpha2,
        ease: 'expo',
        overwrite: 'auto'
      });
    }; // Show Animation Rotate


    var showAnimationRotate = function showAnimationRotate(elem) {
      var show = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
      var rotate1 = show ? '90' : 0;
      var rotate2 = show ? 0 : '90';
      var autoAlpha1 = show ? 0 : 1;
      var autoAlpha2 = show ? 1 : 0;
      gsap.fromTo(elem, {
        rotate: rotate1,
        autoAlpha: autoAlpha1
      }, {
        duration: 1.25,
        rotate: rotate2,
        autoAlpha: autoAlpha2,
        ease: 'expo',
        overwrite: 'auto'
      });
    }; // Text


    ScrollTrigger.create({
      markers: false,
      once: true,
      // start: 'top bottom',
      trigger: text.get(0),
      onEnter: function onEnter() {
        showAnimation(text.get(0));
      },
      onLeaveBack: function onLeaveBack() {
      }
    }); // Image

    ScrollTrigger.create({
      markers: false,
      once: true,
      // start: 'top bottom',
      trigger: image.get(0),
      onEnter: function onEnter() {
        showAnimationRotate(image.get(0));
      },
      onLeaveBack: function onLeaveBack() {
      }
    });
  });
};
"use strict";

/* eslint-disable no-unused-vars */

/* eslint-disable no-undef */

/* eslint-disable no-mixed-spaces-and-tabs */
var sectionBigVideo = function sectionBigVideo() {
  jQuery('.section-big-video').each(function () {
    var section = jQuery(this);
    var video = jQuery(this).find('video').get(0);
    var playPause = jQuery(this).find('button');
    var actions = section.find('.big-video-actions');

    function launchIntoFullscreen(element) {
      if (element.requestFullscreen) {
        element.requestFullscreen();
      } else if (element.mozRequestFullScreen) {
        element.mozRequestFullScreen();
      } else if (element.webkitRequestFullscreen) {
        element.webkitRequestFullscreen();
      } else if (element.msRequestFullscreen) {
        element.msRequestFullscreen();
      } else {
        element.classList.toggle('fullscreen');
      }
    } // Exit Fullscreen


    function exitFullscreen() {
      if (document.exitFullscreen) {
        document.exitFullscreen();
      } else if (document.mozCancelFullScreen) {
        document.mozCancelFullScreen();
      } else if (document.webkitExitFullscreen) {
        document.webkitExitFullscreen();
      }
    }

    actions.on('click', 'a', function (event) {
      event.preventDefault();
      event.stopPropagation();
      var anchor = jQuery(this);

      if (anchor.hasClass('fullscreen')) {
        var fullscreenElement = document.fullscreenElement || document.mozFullScreenElement || document.webkitFullscreenElement || document.msFullscreenElement;

        if (fullscreenElement) {
          section.removeClass('fullscreen');
          exitFullscreen();
        } else {
          section.addClass('fullscreen');
          launchIntoFullscreen(section.get(0));
        }
      }
    });

    function onVideoClick() {
      if (video.paused) {
        video.play();
        playPause.addClass('paused');
        section.addClass('is-playing');
      } else {
        video.pause();
        playPause.removeClass('paused');
        section.removeClass('is-playing');
      }
    } //playPause.on('click', onVideoClick);


    section.on('click', onVideoClick);
    video.addEventListener('ended', function () {
      video.pause(); // video.currentTime( 0 );

      playPause.removeClass('paused');
      section.removeClass('is-playing');
    });
  });
};

var sectionBigVideoReveal = function sectionBigVideoReveal() {
  jQuery('.section-big-video').each(function () {
    var ease = 'power1.in';
    var section = jQuery(this);
    var top = section.find('.overlay-top');
    var bottom = section.find('.overlay-bottom');
    var left = section.find('.overlay-left');
    var right = section.find('.overlay-right');
    var header = jQuery('#color-band-header');
    var offset = Site.headerHeightSticky;
    var start = '-70%';

    if (header.hasClass('with-subheader')) {
      offset = Site.headerHeightStickyWithBannerMobile + 250;
      start = '-300%';

      if (window.innerWidth >= 1024) {
        offset = Site.headerHeightStickyWithBanner;
      }
    }

    gsap.timeline({
      scrollTrigger: {
        trigger: section.get(0),
        scrub: 0,
        markers: false,
        start: start,
        end: "-".concat(offset + 20, "px")
      }
    }).fromTo(top.get(0), {
      y: 0
    }, {
      ease: ease,
      y: '-100%',
      duration: 1
    }, 0).fromTo(bottom.get(0), {
      y: 0
    }, {
      ease: ease,
      y: '100%',
      duration: 1
    }, 0).fromTo(left.get(0), {
      x: 0
    }, {
      ease: ease,
      x: '-100%',
      duration: 1
    }, 0).fromTo(right.get(0), {
      x: 0
    }, {
      ease: ease,
      x: '100%',
      duration: 1
    }, 0);
  });
};
"use strict";

/* eslint-disable no-unused-vars */

/* eslint-disable no-undef */
var sectionBeliefsDesktop = function sectionBeliefsDesktop(el) {
  var section = jQuery(el);
  var timeoutFn = null;
  var timeout = 800;
  var items = section.find('.core-belief-item');
  var numbers = items.find('.core-belief-number');
  var bodies = items.find('.core-belief-body');

  gsap.set(numbers.toArray(), {
    autoAlpha: 0
  });
  gsap.set(bodies.toArray(), {
    autoAlpha: 0
  }); // Module Animation

  var showAnimation = function showAnimation(elem) {
    var show = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
    var y1 = show ? '100%' : 0;
    var y2 = show ? 0 : '100%';
    var autoAlpha1 = show ? 0 : 1;
    var autoAlpha2 = show ? 1 : 0;
    gsap.timeline().staggerFromTo(elem, 0.5, {
      y: y1,
      autoAlpha: autoAlpha1
    }, {
      duration: 1.25,
      y: y2,
      autoAlpha: autoAlpha2,
      ease: 'expo',
      overwrite: 'auto'
    }, 0.3);
  };

  ScrollTrigger.create({
    markers: false,
    once: true,
    // start: 'top bottom',
    trigger: items.get(0),
    onEnter: function onEnter() {
      showAnimation(numbers.toArray());

      if (timeoutFn) {
        clearTimeout(timeoutFn);
      }

      timeoutFn = setTimeout(function () {
        showAnimation(bodies.toArray());
      }, timeout);
    },
    onLeaveBack: function onLeaveBack() {// showAnimation(numbers.toArray(), false);
      // if (timeoutFn) {
      //   clearTimeout(timeoutFn);
      // }
      // timeoutFn = setTimeout(function () {
      //   showAnimation(bodies.toArray(), false);
      // }, timeout);
    }
  });
};

var sectionBeliefsMobile = function sectionBeliefsMobile(el) {
  var section = jQuery(el);
  section.find('.core-belief-item-mobile').each(function () {
    var item = jQuery(this);
    var number = item.find('.core-belief-number');
    var body = item.find('.core-belief-body'); // First Hide The Elements

    gsap.set([body.get(0), number.get(0)], {
      autoAlpha: 0
    });

    var showAnimation = function showAnimation(elem) {
      var operator = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
      var show = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
      var x1 = show ? 100 * operator : 0;
      var x2 = show ? 0 : 100 * operator;
      var autoAlpha1 = show ? 0 : 1;
      var autoAlpha2 = show ? 1 : 0;
      gsap.fromTo(elem, {
        x: x1,
        autoAlpha: autoAlpha1
      }, {
        duration: 1.25,
        x: x2,
        autoAlpha: autoAlpha2,
        ease: 'expo',
        overwrite: 'auto'
      });
    };

    ScrollTrigger.create({
      markers: false,
      trigger: item.get(0),
      once: true,
      onEnter: function onEnter() {
        showAnimation(number.get(0), -1);
        showAnimation(body.get(0));
      },
      onLeaveBack: function onLeaveBack() {
      }
    });
  });
};

var sectionCoreBeliefs = function sectionCoreBeliefs() {
  jQuery('.section-core-beliefs').each(function () {
    sectionBeliefsDesktop(this);
    sectionBeliefsMobile(this);
  });
};
"use strict";

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/* eslint-disable no-undef */
var sectionGoals = function sectionGoals() {
  jQuery('.section-goals').each(function () {
    var section = jQuery(this);
    var data = section.data();
    var wrapper = section.find('.goal-donut-wrapper');
    var donut = section.find('.goal-donut');
    var image = section.find('.goal-donut-image');
    var radius = 0;
    var outerRadius = 0;
    var innerRadius = 0;

    if (!data.items || data.items.length === 0) {
      wrapper.empty();
      return null;
    }

    section.on('goals-hover', function (e, goal) {
      var goalActive = section.find('.goal-item.active');
      var goalToActive = section.find('#goal-item-' + goal.index);

      if (goalActive.attr('id') === 'goal-item-' + goal.index) {
        return null;
      }

      goalActive.hide();
      goalToActive.fadeIn();
      goalActive.removeClass('active');
      goalToActive.addClass('active');
    }); // http://bl.ocks.org/erichoco/6694616

    var pathAnim = function pathAnim(path, dir) {
      var radiusFactor = 20;

      if (window.innerWidth <= 1024) {
        radiusFactor = 10;
      }

      switch (dir) {
        case 0:
          d3.select(path).transition().duration(500).ease(d3.easeBounce).attr('d', d3.arc().innerRadius(innerRadius).outerRadius(radius));
          break;

        case 1:
          d3.select(path).transition().attr('d', d3.arc().innerRadius(innerRadius).outerRadius(radius + radiusFactor));
          break;
      }
    };

    var pathAnim2 = function pathAnim2(path, dir) {
      var radiusFactor = 7;

      if (window.innerWidth <= 1024) {
        radiusFactor = 3;
      }

      switch (dir) {
        case 0:
          d3.select(path).transition().duration(500).ease(d3.easeBounce).attr('d', d3.arc().innerRadius(innerRadius).outerRadius(radius));
          break;

        case 1:
          d3.select(path).transition().attr('d', d3.arc().innerRadius(innerRadius).outerRadius(radius + radiusFactor));
          break;
      }
    };

    var buildDonut = function buildDonut() {
      // Remove all
      donut.empty(); // set the dimensions and margins of the graph

      var width = donut.width();
      var height = donut.width();
      var margin = 40;
      var innerRadiusFactor = 0.65; // Small

      if (window.innerWidth <= 1024) {
        margin = 10;
        innerRadiusFactor = 0.6;
      } 


      radius = Math.min(width, height) / 2 - margin;
      outerRadius = radius;
      innerRadius = radius * innerRadiusFactor;
      var imageSize = radius - 10;
      image.width(imageSize);
      image.height(imageSize);
      image.css({
        top: '50%',
        marginTop: "-".concat(imageSize / 2, "px"),
        left: '50%',
        marginLeft: "-".concat(imageSize / 2, "px")
      });
      var arc = d3.arc().outerRadius(outerRadius) // This is the size of the donut hole
      .innerRadius(innerRadius);
      var pie = d3.pie().sort(null).value(function (d) {
        return d.portfolio_number;
      }); // append the svg object

      var svg = d3.select(donut.get(0)).append('svg').attr('width', width).attr('height', height).append('g').attr('transform', 'translate(' + width / 2 + ',' + height / 2 + ')');
      var g = svg.selectAll('.arc').data(pie(data.items)).enter().append('g').attr('class', 'arc');
      g.append('path').attr('d', arc).attr('fill', function (d) {
        return d.data.color;
      }).attr('stroke', function (d) {
        return d.data.color;
      }).attr('index', function (d) {
        return d.index;
      }).on('click', function (e, d) {
        // Is active
        var isActive = d3.select(this).classed('active');

        if (isActive) {
          return null;
        }

        var pathActive = svg.select('path.active');

        if (!pathActive.empty()) {
          pathAnim(pathActive.node(), 0);
          pathActive.classed('active', false); //
        } // pathAnim(this, 0);
        // Trigger Event


        section.trigger('goals-hover', d); // Anim

        pathAnim(this, 1); // Add Class Active

        d3.select(this).classed('active', true); //
      }).on('mouseover', function (e, d) {
        // Is active
        var isActive = d3.select(this).classed('hover-active');

        if (isActive) {
          return null;
        }

        var isActive2 = d3.select(this).classed('active');

        if (isActive2) {
          return null;
        } // pathAnim(this, 0);
        // Trigger Event
        //section.trigger('goals-hover', d);
        // Anim


        pathAnim2(this, 1); // Add Class Active

        d3.select(this).classed('hover-active', true); //
      }).on('mouseout', function () {
        var isActive2 = d3.select(this).classed('active');

        if (isActive2) {
          return null;
        }

        pathAnim2(this, 0);
        d3.select(this).classed('hover-active', false); //
      }); // Rotation of Text
      // https://stackoverflow.com/questions/41949849/d3-text-rotation-in-a-pie-chart

      pie(data.items).forEach(function (d) {
        var _arc$centroid = arc.centroid(d),
            _arc$centroid2 = _slicedToArray(_arc$centroid, 2),
            x = _arc$centroid2[0],
            y = _arc$centroid2[1];

        var label = d.data.title;
        var rotation = d.endAngle < Math.PI ? (d.startAngle / 2 + d.endAngle / 2) * 180 / Math.PI : (d.startAngle / 2 + d.endAngle / 2 + Math.PI) * 180 / Math.PI;
        svg.append('text').attr('class', 'text-arc').attr('text-anchor', 'middle').attr('alignment-baseline', 'middle').attr('transform', 'translate(' + [x, y] + ') rotate(-90) rotate(' + rotation + ')').text(label);
      }); // Activate First Path

      var firstPath = svg.select("path[index='0']");
      pathAnim(firstPath.node(), 1);
      d3.select(firstPath.node()).classed('active', true); //
      // console.log(firstPath);
    };

    buildDonut();
    jQuery(window).on('resize', function () {
      buildDonut();
    });
  });
};

jQuery(function () {
  (function () {
    if (0 < jQuery('.section-goals').length) {
      sectionGoals();
    }
  })();
});
"use strict";

/* eslint-disable no-undef */

/* eslint-disable no-unused-vars */
var sectionImpactAmbition = function sectionImpactAmbition() {
  jQuery('.section-impact-ambition').each(function () {
    var section = jQuery(this);
    var items = section.find('.impact-ambition-item ');

    var impactAmbitionMobile = function impactAmbitionMobile() {
      var height = 0;
      items.each(function () {
        var value = jQuery(this).height();
        height = value > height ? value : height;
      });
      items.css('height', height);
    };

    var resetStyles = function resetStyles() {
      items.css('height', 'auto');
    };

    if (window.innerWidth < 1024) {
      impactAmbitionMobile();
    }

    jQuery(window).on('resize', function () {
      if (window.innerWidth < 1024) {
        impactAmbitionMobile();
      } else {
        resetStyles();
      }
    });
  });
};

jQuery(function () {
  (function () {
    if (jQuery('.section-impact-ambition').length > 0) {
      sectionImpactAmbition();
    }
  })();
});
"use strict";

/* eslint-disable no-undef */
var sectionImpactStats = function sectionImpactStats() {
  jQuery('.section-impact-stats').each(function () {
    var section = jQuery(this);
    var carousel = section.find('.carousel-impact-stats');
    var navigation = section.find('.carousel-impact-stats-navigation');
    var navigationPrev = section.find('.prev');
    var navigationNext = section.find('.next'); // Check if has navigation

    function checkIfHasNavigation(slick) {
      if (slick.slideCount > slick.options.slidesToShow) {
        navigationNext.removeClass('disabled');
        navigation.removeClass('d-none');
      } else {
        navigationNext.addClass('disabled');
        navigationPrev.addClass('disabled');
        navigation.addClass('d-none');
      }
    } // Navigation Flow


    function navigationFlow(slick) {
      if (slick.currentSlide >= slick.slideCount - slick.options.slidesToShow) {
        navigationNext.addClass('disabled');
      } else {
        navigationNext.removeClass('disabled');
      }

      if (0 == slick.currentSlide) {
        navigationPrev.addClass('disabled');
      } else {
        navigationPrev.removeClass('disabled');
      }
    }

    carousel.on('init', function (event, slick) {
      checkIfHasNavigation(slick);
      navigationFlow(slick);
    });
    carousel.slick({
      centerMode: false,
      infinite: false,
      slidesToScroll: 1,
      arrows: false,
      dots: false,
      autoplay: false,
      speed: 900,
      rows: 0,
      slidesToShow: 1.6
    });
    carousel.on('afterChange', function (event, slick) {
      navigationFlow(slick);
    }); // Navigation

    navigationPrev.on('click', function (e) {
      e.stopPropagation();
      e.preventDefault();
      carousel.slick('slickPrev');
    });
    navigationNext.on('click', function (e) {
      e.stopPropagation();
      e.preventDefault();
      carousel.slick('slickNext');
    });
  });
};

jQuery(function () {
  (function () {
    if (0 < jQuery('.section-impact-stats').length) {
      sectionImpactStats();
    }
  })();
});
"use strict";

/* eslint-disable no-undef */
var sectionMission = function sectionMission() {
  jQuery('.section-mission').each(function () {
    var section = jQuery(this);
    var text1 = section.find('.text-content-1');
    var text2 = section.find('.text-content-2');
    var image = section.find('.img-content');
    var secondContent = section.find('.second-content'); // First Hide The Elements

    gsap.set([text1.get(0), text2.get(0), secondContent.get(0)], {
      autoAlpha: 0
    }); // Generic Animation of module

    var showAnimation = function showAnimation(elem) {
      var show = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
      var y1 = show ? '100%' : 0;
      var y2 = show ? 0 : '100%';
      var autoAlpha1 = show ? 0 : 1;
      var autoAlpha2 = show ? 1 : 0;
      gsap.fromTo(elem, {
        y: y1,
        autoAlpha: autoAlpha1
      }, {
        duration: 1.25,
        y: y2,
        autoAlpha: autoAlpha2,
        ease: 'expo',
        overwrite: 'auto'
      });
    };

    var showAnimationScale = function showAnimationScale(elem) {
      var show = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
      var y1 = show ? '20%' : 0;
      var y2 = show ? 0 : '20%';
      var scale1 = show ? 0.6 : 1;
      var scale2 = show ? 1 : 0.6;
      var autoAlpha1 = show ? 0 : 1;
      var autoAlpha2 = show ? 1 : 0;
      gsap.fromTo(elem, {
        y: y1,
        scale: scale1,
        autoAlpha: autoAlpha1
      }, {
        duration: 1.25,
        y: y2,
        scale: scale2,
        autoAlpha: autoAlpha2,
        ease: 'expo',
        overwrite: 'auto'
      });
    };

    var showAnimationRotation = function showAnimationRotation(elem) {
      var show = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
      var rotate1 = show ? '90' : 0;
      var rotate2 = show ? 0 : '90';
      var autoAlpha1 = show ? 0 : 1;
      var autoAlpha2 = show ? 1 : 0;
      gsap.fromTo(elem, {
        rotate: rotate1,
        autoAlpha: autoAlpha1
      }, {
        duration: 1.25,
        rotate: rotate2,
        autoAlpha: autoAlpha2,
        ease: 'expo',
        overwrite: 'auto'
      });
    }; // Text 1


    ScrollTrigger.create({
      trigger: text1.get(0),
      once: true,
      onEnter: function onEnter() {
        showAnimation(text1.get(0));
      },
      onLeaveBack: function onLeaveBack() {// showAnimation(text1.get(0), false);
      }
    }); // Text 2

    ScrollTrigger.create({
      trigger: text2.get(0),
      once: true,
      onEnter: function onEnter() {
        showAnimation(text2.get(0));
      },
      onLeaveBack: function onLeaveBack() {// showAnimation(text2.get(0), false);
      }
    }); // Second Content
    // Responsive

    var end = '';

    var createScrollTriggers = function createScrollTriggers(end) {
      ScrollTrigger.create({
        trigger: secondContent.get(0),
        markers: false,
        start: 'top bottom',
        end: end,
        once: true,
        // end: end,
        onEnter: function onEnter() {
          showAnimationScale(secondContent.get(0));
        },
        onLeaveBack: function onLeaveBack() {// showAnimationScale(secondContent.get(0), false);
        },
        onLeave: function onLeave() {// showAnimationRotation(image.get(0), false);
        },
        onEnterBack: function onEnterBack() {// showAnimationRotation(image.get(0));
        }
      });
    }; // Create scroll trigger according media query (cross)


    ScrollTrigger.matchMedia({
      '(min-width:768px)': function minWidth768px() {
        end = '=+20%';
        createScrollTriggers(end);
      },
      '(max-width:767px)': function maxWidth767px() {
        end = '=+10%';
        createScrollTriggers(end);
      }
    });
  });
}; // jQuery(function () {
//   (function () {
//   })();
// });
"use strict";

/* eslint-disable no-unused-vars */

/* eslint-disable no-undef */
var sectionQuantifiyingImpactDesktop = function sectionQuantifiyingImpactDesktop() {
  // With alpha editor is more easy :p
  var getOffset = function getOffset() {
    var offset = 48;
    var header = jQuery('#color-band-header');

    if (header.hasClass('with-subheader')) {
      offset = 100;

      if (1024 <= window.innerWidth) {
        offset = 140;
      }
    }

    return offset;
  };

  jQuery('.section-quantifiying-impact').each(function () {
    // var d = new Date().getTime();
    // // uuid
    // var uuid = 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
    //   var r = (d + Math.random() * 16) % 16 | 0;
    //   d = Math.floor(d / 16);
    //   return (c === 'x' ? r : (r & 0x3) | 0x8).toString(16);
    // });
    // ID
    // const triggerID = `trigger-${uuid}`;
    // Elements
    var section = jQuery(this).find('.container');
    var wrapper = section.find('.section-quantifiying-impact-animation');
    var topSVG = section.find('.section-quantifiying-impact-animation-top-container svg');
    var topSVG2 = section.find('.section-quantifiying-impact-animation-top-container-2 svg');
    var item1 = section.find('.section-quantifiying-impact-item1');
    var item2 = section.find('.section-quantifiying-impact-item2');
    var offset = getOffset(); // Timeline

    var t = gsap.timeline({
      scrollTrigger: {
        // id: triggerID,
        // Trigger Section
        trigger: wrapper.get(0),
        // Pint First Content
        pin: wrapper.get(0),
        // @TODO i have change this to test
        // Start top scroller offset
        start: "-=40px ".concat(offset, "px"),
        // start: `-=${offset}px`,
        end: '+=1000',
        pinSpacing: true,
        markers: false,
        scrub: true,
        onEnter: function onEnter() {
          // @TODO i put this, because in entrance animation the item 2 is showing, and this cause the elements not being centering
          // First Hide Second  Element
          item2.css({
            display: 'none'
          });
          section.addClass('is-playing');
        },
        onEnterBack: function onEnterBack() {
          section.addClass('is-playing');
        },
        onLeave: function onLeave() {
          section.removeClass('is-playing');
        }
      }
    }).fromTo(topSVG.get(0), {
      rotate: -180,
      onEnter: function onEnter() {
        item2.css({
          display: 'none'
        });
      }
    }, {
      rotate: 0,
      onComplete: function onComplete() {
        return topSVG.parent().css({
          overflow: 'visible'
        });
      },
      onReverseComplete: function onReverseComplete() {
        return topSVG.parent().css({
          overflow: 'hidden'
        });
      }
    }, '0').fromTo(item1.get(0), {
      display: 'block',
      y: 800,
      opacity: 0
    }, {
      opacity: 1,
      y: 0
    }, '0').fromTo(item1.get(0), {
      opacity: 1,
      y: 0
    }, {
      opacity: 0,
      y: -50,
      display: 'none',
      onComplete: function onComplete() {
        item2.css({
          display: 'block'
        });
      }
    }, '1').fromTo(topSVG.get(0), {
      rotate: 0
    }, {
      rotate: 180,
      onReverseComplete: function onReverseComplete() {
        topSVG.parent().css({
          overflow: 'hidden'
        }) && item1.css({
          display: 'block'
        }) && item2.css({
          display: 'none'
        });
      }
    }, '2').fromTo(item2.get(0), {
      display: 'block',
      opacity: 0,
      y: 800
    }, {
      opacity: 1,
      y: 0
    }, '2').fromTo(item2.get(0), {
      opacity: 1,
      y: 0
    }, {
      opacity: 0,
      y: -50,
      display: 'none'
    }, '3').fromTo(topSVG2.get(0), {
      rotate: -180
    }, {
      rotate: 0
    }, '4');
  });
};

var sectionQuantifiyingImpactMobile = function sectionQuantifiyingImpactMobile() {
  // With alpha editor is more easy :p
  var getOffset = function getOffset() {
    var offset = 48;
    var header = jQuery('#color-band-header');

    if (header.hasClass('with-subheader')) {
      offset = 100;

      if (1024 <= window.innerWidth) {
        offset = 140;
      }
    }

    return offset;
  };

  jQuery('.section-quantifiying-impact').each(function () {
    // Elements
    var section = jQuery(this).find('.container');
    var wrapper = section.find('.section-quantifiying-impact-animation');
    var topSVG = section.find('.section-quantifiying-impact-animation-top-container svg');
    var topSVG2 = section.find('.section-quantifiying-impact-animation-top-container-2 svg');
    var item1 = section.find('.section-quantifiying-impact-item1');
    var item2 = section.find('.section-quantifiying-impact-item2');
    var offset = getOffset(); // Timeline

    var t = gsap.timeline({
      scrollTrigger: {
        // id: triggerID,
        // Trigger Section
        trigger: wrapper.get(0),
        // Pint First Content
        pin: wrapper.get(0),
        // @TODO i have change this to test
        // Start top scroller offset
        start: "-=40px ".concat(offset, "px"),
        // start: `-=${offset}px`,
        // @TODO to large 8000
        end: '+=2700',
        pinSpacing: true,
        markers: false,
        scrub: true,
        onEnter: function onEnter() {
          // @TODO i put this, because in entrance animation the item 2 is showing, and this cause the elements not being centering
          // First Hide Second  Element
          item2.css({
            display: 'none'
          });
          section.addClass('is-playing');
        },
        onEnterBack: function onEnterBack() {
          section.addClass('is-playing');
        },
        onLeave: function onLeave() {
          section.removeClass('is-playing');
        }
      }
    }).fromTo(topSVG.get(0), {
      rotate: -180,
      onEnter: function onEnter() {
        item2.css({
          display: 'none'
        });
      }
    }, {
      rotate: 0,
      onComplete: function onComplete() {
        return topSVG.parent().css({
          overflow: 'visible'
        });
      },
      onReverseComplete: function onReverseComplete() {
        return topSVG.parent().css({
          overflow: 'hidden'
        });
      }
    }, '0').fromTo(item1.get(0), {
      display: 'block',
      y: 800,
      opacity: 0
    }, {
      opacity: 1,
      y: 0
    }, '0').to({}, {
      duration: 1
    }, '1').fromTo(item1.get(0), {
      opacity: 1,
      y: 0
    }, {
      opacity: 0,
      y: -20,
      display: 'none',
      onComplete: function onComplete() {
        item2.css({
          display: 'block'
        });
      }
    }, '1').to({}, {
      duration: 2
    }, '1').fromTo(topSVG.get(0), {
      rotate: 0
    }, {
      rotate: 180,
      onReverseComplete: function onReverseComplete() {
        topSVG.parent().css({
          overflow: 'hidden'
        }) && item1.css({
          display: 'block'
        }) && item2.css({
          display: 'none'
        });
      }
    }, '2').fromTo(item2.get(0), {
      display: 'block',
      opacity: 0,
      y: 800
    }, {
      opacity: 1,
      y: 0
    }, '2').fromTo(item2.get(0), {
      opacity: 1,
      y: 0
    }, {
      opacity: 0,
      y: -20,
      display: 'none'
    }, '3').fromTo(topSVG2.get(0), {
      rotate: -180
    }, {
      rotate: 0
    }, '4');
  });
};

var sectionQuantifiyingImpact = function sectionQuantifiyingImpact() {
  var section = jQuery('.section-quantifiying-impact');
  var wrapper = section.find('.section-quantifiying-impact-animation');
  var topSVG = section.find('.section-quantifiying-impact-animation-top-container svg');
  var topSVG2 = section.find('.section-quantifiying-impact-animation-top-container-2 svg');
  var item1 = section.find('.section-quantifiying-impact-item1');
  var item2 = section.find('.section-quantifiying-impact-item2');
  ScrollTrigger.saveStyles(section.toArray());
  ScrollTrigger.saveStyles(wrapper.toArray());
  ScrollTrigger.saveStyles(topSVG.toArray());
  ScrollTrigger.saveStyles(topSVG2.toArray());
  ScrollTrigger.saveStyles(item1.toArray());
  ScrollTrigger.saveStyles(item2.toArray());
  ScrollTrigger.matchMedia({
    // Desktop
    '(min-width: 1024px)': function minWidth1024px() {
      sectionQuantifiyingImpactDesktop();
    },
    // Mobile
    '(max-width: 1023px)': function maxWidth1023px() {
      sectionQuantifiyingImpactMobile();
    }
  });
};
"use strict";

/* eslint-disable no-unused-vars */

/* eslint-disable no-undef */
var sectionSlideUpDesktop = function sectionSlideUpDesktop() {
  jQuery('.section-slide-up').each(function () {
    var section = jQuery(this);
    var triggerID = new Date().getTime(); // First Content

    var firstContent = section.find('.first-content-wrapper');
    var slideUpPinWrapper = section.find('.slide-up-pin'); // Overlay to cover first comtent

    var overlay = section.find('.slide-up-content'); // First Content Height

    var firstContentH = firstContent.outerHeight(); // Get offset

    var getOffset = function getOffset() {
      var offset = Site.headerHeightSticky;
      var header = jQuery('#color-band-header');

      if (header.hasClass('with-subheader')) {
        offset = Site.headerHeightStickyWithBannerMobile;

        if (1024 <= window.innerWidth) {
          offset = Site.headerHeightStickyWithBanner;
        }
      }

      return offset;
    }; // Animation


    var initAnimation = function initAnimation() {
      var offset = getOffset(); // Scroll Trigger

      timeline = gsap.timeline({
        scrollTrigger: {
          id: "".concat(triggerID, "_slideup"),
          // Trigger Section
          trigger: section.get(0),
          // Pint First Content
          pin: slideUpPinWrapper.get(0),
          // Start top scroller offset
          start: "top ".concat(offset, "px"),
          end: "".concat(firstContentH / 2, "px"),
          pinSpacing: false,
          markers: false,
          scrub: true // onEnter: function () {
          //   items.removeClass('active');
          // },
          // onEnterBack: function () {
          //   // items.removeClass('active');
          // },
          // onLeave: function () {
          //   // items.addClass('active');
          // }

        }
      }).fromTo(overlay.get(0), {
        y: "".concat(0, "px")
      }, {
        y: "-100%"
      });
    }; // Init


    initAnimation();
  });
};

var sectionSlideUpMobile = function sectionSlideUpMobile() {
  jQuery('.section-slide-up').each(function () {
    var section = jQuery(this);
    var triggerID = new Date().getTime();
    var slideUpPinWrapper = section.find('.slide-up-pin'); // Overlay to cover first comtent

    var overlay = section.find('.slide-up-content'); // Items

    var items = section.find('.slide-up-box-item'); // OFF

    items.off('click.slide-up'); // Get offset

    var getOffset = function getOffset() {
      var offset = Site.headerHeightSticky;
      var header = jQuery('#color-band-header');

      if (header.hasClass('with-subheader')) {
        offset = Site.headerHeightStickyWithBannerMobile;

        if (window.innerWidth >= 1024) {
          offset = Site.headerHeightStickyWithBanner;
        }
      }

      return offset;
    }; // Animation


    var initAnimation = function initAnimation() {
      var offset = getOffset(); // Scroll Trigger

      timeline = gsap.timeline({
        scrollTrigger: {
          id: "".concat(triggerID, "_slideup_mobile"),
          // Trigger Section
          trigger: section.get(0),
          // Pint First Content
          pin: slideUpPinWrapper.get(0),
          // Start top scroller offset
          start: "-=".concat(offset, "px"),
          end: 'bottom',
          pinSpacing: true,
          markers: false,
          scrub: true // onEnter: function () {
          //   items.removeClass('active');
          // },
          // onEnterBack: function () {
          //   items.removeClass('active');
          // },
          // onLeave: function () {
          //   items.addClass('active');
          // }

        }
      }).fromTo(overlay.get(0), {
        y: '100%'
      }, {
        y: '0'
      }, '0');
    };

    var initEvents = function initEvents() {
      var timeout = null;
      items.on('click.slide-up', function () {
        var el = jQuery(this);

        if (timeout) {
          clearTimeout(timeout);
        } // if ( ! el.hasClass( 'active' )  ) {
        // 	return null;
        // }


        if (el.hasClass('active-mobile')) {
          return null;
        }

        var firstTime = section.find('.slide-up-box-item.active-mobile').length === 0;
        items.removeClass('active-mobile');

        if (firstTime) {
          el.addClass('active-mobile');
        } else {
          timeout = setTimeout(function () {
            el.addClass('active-mobile');
          }, 600);
        }
      });
    };

    var initAnimation2 = function initAnimation2() {
      var section = jQuery('.section-slide-up');
      section.find('.slide-up-column-item').each(function () {
        var item = jQuery(this);
        var number = item.find('h1');
        var body = item.find('h5'); // First Hide The Elements

        gsap.set([body.get(0), number.get(0)], {
          autoAlpha: 0
        });

        var showAnimation = function showAnimation(elem) {
          var operator = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
          var show = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
          var x1 = show ? 100 * operator : 0;
          var x2 = show ? 0 : 100 * operator;
          var autoAlpha1 = show ? 0 : 1;
          var autoAlpha2 = show ? 1 : 0;
          gsap.fromTo(elem, {
            x: x1,
            autoAlpha: autoAlpha1
          }, {
            duration: 1.25,
            x: x2,
            autoAlpha: autoAlpha2,
            ease: 'expo',
            overwrite: 'auto'
          });
        };

        ScrollTrigger.create({
          markers: false,
          trigger: item.get(0),
          once: true,
          onEnter: function onEnter() {
            showAnimation(number.get(0), -1);
            showAnimation(body.get(0));
          },
          onLeaveBack: function onLeaveBack() {// showAnimation(number.get(0), -1, false);
            // showAnimation(body.get(0), 1, false);
          }
        });
      });
      var items = jQuery('.slideup-box-items .slide-up-box-item');
      items.each(function () {
        var item = jQuery(this);
        var text = item.find('.body-text-content');

        var showAnimation = function showAnimation(elem) {
          var show = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
          var autoAlpha1 = show ? 0 : 1;
          var autoAlpha2 = show ? 1 : 0;
          gsap.fromTo(elem, {
            //x: x1,
            autoAlpha: autoAlpha1
          }, {
            duration: 1.25,
            //x: x2,
            autoAlpha: autoAlpha2,
            ease: 'expo',
            overwrite: 'auto'
          });
        };

        ScrollTrigger.create({
          markers: false,
          trigger: item.get(0),
          once: true,
          onEnter: function onEnter() {
            showAnimation(text.get(0));
          },
          onLeaveBack: function onLeaveBack() {// showAnimation(number.get(0), -1, false);
            // showAnimation(body.get(0), 1, false);
          }
        });
      });
    }; // Init
    //initAnimation();


    initAnimation2();
    initEvents();
  });
};

var sectionSlideUp = function sectionSlideUp() {
  var section = jQuery('.section-slide-up');
  var firstContent = section.find('.first-content-wrapper');
  var slideUpPinWrapper = section.find('.slide-up-pin');
  var overlay = section.find('.slide-up-content');
  ScrollTrigger.saveStyles(section.toArray());
  ScrollTrigger.saveStyles(firstContent.toArray());
  ScrollTrigger.saveStyles(slideUpPinWrapper.toArray());
  ScrollTrigger.saveStyles(overlay.toArray());
  ScrollTrigger.matchMedia({
    // Desktop
    '(min-width: 1024px)': function minWidth1024px() {//sectionSlideUpDesktop();
    },
    // Mobile
    '(max-width: 1023px)': function maxWidth1023px() {
      sectionSlideUpMobile();
    }
  });
};
"use strict";

/* eslint-disable no-unused-vars */

/* eslint-disable no-undef */
// https://codepen.io/mkultr4/pen/MWVyaog
var sectionWeFocusDesktop = function sectionWeFocusDesktop() {
  jQuery('.section-we-focus').each(function () {
    var section = jQuery(this);
    var caption = section.find('.we-focus-caption');
    var steps = section.find('.single-step');
    var stepWrapper = section.find('.stepped-animation');
    var scrollTrigger = null;
    var stepsTimeline = null;
    var triggerID = new Date().getTime();

    var initAnimation = function initAnimation() {
      gsap.set(steps.toArray(), {
        autoAlpha: 0
      }); // Duration per element 250

      var pinDistance = (steps.length + 2) * 250;
      /* section */

      scrollTrigger = ScrollTrigger.create({
        id: "".concat(triggerID, "_wefocus"),
        trigger: section.get(0),
        start: 'center center',
        end: '+=' + pinDistance,
        pin: section.get(0),
        markers: false
      });
      /* texts inside section */

      stepsTimeline = gsap.timeline({
        scrollTrigger: {
          id: "".concat(triggerID, "_wefocus_step"),
          trigger: stepWrapper.get(0),
          start: 'center center',
          end: '+=' + pinDistance,
          scrub: true
        }
      }); // loop through each step and add a callback into the timeline, spaced equally (1 second apart just to make things simple)

      steps.each(function (i, step) {
        stepsTimeline.add(function () {
          // if scrolling backward, we need to invert which element fades in or out
          var forward = 0 < stepsTimeline.scrollTrigger.direction,
              inEl = forward ? step : steps[i - 1],
              outEl = forward ? steps[i - 1] : step; // Remove active

          var letters = caption.find('[data-slide]');
          letters.removeClass('active');

          if (outEl) {
            gsap.to(outEl, {
              autoAlpha: 0,
              duration: 0.3,
              overwrite: true
            });
          }

          if (inEl) {
            var data = jQuery(inEl).data();
            var letter = caption.find("[data-slide='".concat(data.index, "']"));

            if (letter) {
              letter.addClass('active');
            }

            gsap.to(inEl, {
              autoAlpha: 1,
              duration: 0.3,
              delay: 0.3,
              overwrite: true
            });
          }
        }, i || 0.001);
      }); // add blank space to the end of the timeline so that the last element stays for a bit before unpinning.

      stepsTimeline.to({}, {
        duration: 1
      });
    }; // Init


    if (1024 <= window.innerWidth) {
      initAnimation();
    }
  });
};

var sectionWeFocusMobile = function sectionWeFocusMobile() {
  jQuery('.section-we-focus  .single-step-mobile').each(function () {
    var section = jQuery(this);
    var title = section.find('.title');
    var subtitle = section.find('.subtitle');
    var p = section.find('.paragraph');
    var scrollTrigger = null;
    var timelineTitle = null;
    var timeline = null;

    var initAnimation = function initAnimation() {
      timelineTitle = gsap.timeline();
      timeline = gsap.timeline();
      timeline.paused(true);
      timelineTitle.paused(true);
      scrollTrigger = ScrollTrigger.create({
        markers: false,
        once: true,
        trigger: section.get(0),
        onEnter: function onEnter() {
          timelineTitle.play();
        },
        onLeaveBack: function onLeaveBack() {// timelineTitle.reverse();
        }
      }); // Title

      timelineTitle.fromTo(title.get(0), {
        autoAlpha: 0,
        y: 100
      }, {
        autoAlpha: 1,
        y: 0
      }); // timelineTitle.eventCallback('onReverseComplete', function () {
      //   title.removeClass('active');
      //   timeline.reverse();
      // });

      timelineTitle.eventCallback('onComplete', function () {
        title.addClass('active');
        timeline.play();
      }); // Body

      timeline.fromTo(subtitle.get(0), {
        autoAlpha: 0,
        y: 100
      }, {
        autoAlpha: 1,
        y: 0
      }).fromTo(p.get(0), {
        autoAlpha: 0,
        y: 100
      }, {
        autoAlpha: 1,
        y: 0
      });
    };

    initAnimation();
  });
};

var sectionWeFocus = function sectionWeFocus() {
  // Desktop
  var section = jQuery('.section-we-focus');
  var caption = section.find('.we-focus-caption');
  var steps = section.find('.single-step');
  var stepWrapper = section.find('.stepped-animation');
  ScrollTrigger.saveStyles(section.toArray());
  ScrollTrigger.saveStyles(caption.toArray());
  ScrollTrigger.saveStyles(steps.toArray());
  ScrollTrigger.saveStyles(stepWrapper.toArray()); // Mobile

  var itemsMobile = section.find('.single-step-mobile');
  var title = itemsMobile.find('.title');
  var subtitle = itemsMobile.find('.subtitle');
  var p = itemsMobile.find('.paragraph');
  ScrollTrigger.saveStyles(itemsMobile.toArray());
  ScrollTrigger.saveStyles(title.toArray());
  ScrollTrigger.saveStyles(subtitle.toArray());
  ScrollTrigger.saveStyles(p.toArray());
  ScrollTrigger.matchMedia({
    // Desktop
    '(min-width: 1024px)': function minWidth1024px() {
      sectionWeFocusDesktop();
    },
    // Mobile
    '(max-width: 1023px)': function maxWidth1023px() {
      sectionWeFocusMobile();
    }
  });
};
"use strict";

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
var initCarousels = function initCarousels(wrapper) {
  jQuery('.story-carousel ').each(function () {
    var carousel = jQuery(this);
    var wrapper = carousel.closest('.story-carousel-wrapper');
    var navigation = wrapper.find('.story-carousel-navigation');
    var navigationPrev = navigation.find('.prev');
    var navigationNext = navigation.find('.next'); // Check if has navigation

    function checkIfHasNavigation(slick) {
      if (slick.slideCount > slick.options.slidesToShow) {
        navigationNext.removeClass('disabled');
        navigation.removeClass('d-none');
      } else {
        navigationNext.addClass('disabled');
        navigationPrev.addClass('disabled');
        navigation.addClass('d-none');
      }
    } // Navigation Flow


    function navigationFlow(slick) {
      if (slick.currentSlide >= slick.slideCount - slick.options.slidesToShow) {
        navigationNext.addClass('disabled');
      } else {
        navigationNext.removeClass('disabled');
      }

      if (0 == slick.currentSlide) {
        navigationPrev.addClass('disabled');
      } else {
        navigationPrev.removeClass('disabled');
      }
    }

    carousel.on('init', function (event, slick) {
      checkIfHasNavigation(slick);
      navigationFlow(slick); // descriptionHeight();
    });
    carousel.slick({
      infinite: false,
      arrows: false,
      dots: false,
      autoplay: false,
      speed: 900,
      rows: 0,
      slidesToShow: 1
    });
    carousel.on('afterChange', function (event, slick) {
      navigationFlow(slick);
    }); // Navigation

    navigationPrev.on('click', function (e) {
      e.stopPropagation();
      e.preventDefault();
      carousel.slick('slickPrev');
    });
    navigationNext.on('click', function (e) {
      e.stopPropagation();
      e.preventDefault();
      carousel.slick('slickNext');
    });
  });
  var myCollapsible = wrapper.find('#stories-accordion').get(0);
  console.log(myCollapsible);
  myCollapsible.addEventListener('show.bs.collapse', function (e) {
    var el = jQuery(e.target);
    console.log(e.target);
    el.find('.story-carousel ').each(function () {
      var carousel = jQuery(this);
      console.log(carousel);
      carousel.slick('refresh');
    });
  });
};

jQuery(function () {
  (function () {
    var wrapper = jQuery('.section-stories');

    if (0 == wrapper.length) {
      return null;
    }

    initCarousels(wrapper);
  })();
});
"use strict";

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
var teamLinkTwitter = "\n<a target=\"_blank\" href=\"#twitterUrl\" class=\"social twitter\">\n\t<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 512 512\">\n\t\t<path fill=\"currentColor\" d=\"M459.37 151.716c.325 4.548.325 9.097.325 13.645 0 138.72-105.583 298.558-298.558 298.558-59.452 0-114.68-17.219-161.137-47.106 8.447.974 16.568 1.299 25.34 1.299 49.055 0 94.213-16.568 130.274-44.832-46.132-.975-84.792-31.188-98.112-72.772 6.498.974 12.995 1.624 19.818 1.624 9.421 0 18.843-1.3 27.614-3.573-48.081-9.747-84.143-51.98-84.143-102.985v-1.299c13.969 7.797 30.214 12.67 47.431 13.319-28.264-18.843-46.781-51.005-46.781-87.391 0-19.492 5.197-37.36 14.294-52.954 51.655 63.675 129.3 105.258 216.365 109.807-1.624-7.797-2.599-15.918-2.599-24.04 0-57.828 46.782-104.934 104.934-104.934 30.213 0 57.502 12.67 76.67 33.137 23.715-4.548 46.456-13.32 66.599-25.34-7.798 24.366-24.366 44.833-46.132 57.827 21.117-2.273 41.584-8.122 60.426-16.243-14.292 20.791-32.161 39.308-52.628 54.253z\"></path>\n\t</svg>\n</a>\n";
var teamLinkLinkedin = "\n<a target=\"_blank\" href=\"#linkedinUrl\" class=\"social linkedin\">\n\t<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 448 512\">\n        <path fill=\"currentColor\" d=\"M416 32H31.9C14.3 32 0 46.5 0 64.3v383.4C0 465.5 14.3 480 31.9 480H416c17.6 0 32-14.5 32-32.3V64.3c0-17.8-14.4-32.3-32-32.3zM135.4 416H69V202.2h66.5V416zm-33.2-243c-21.3 0-38.5-17.3-38.5-38.5S80.9 96 102.2 96c21.2 0 38.5 17.3 38.5 38.5 0 21.3-17.2 38.5-38.5 38.5zm282.1 243h-66.4V312c0-24.8-.5-56.7-34.5-56.7-34.6 0-39.9 27-39.9 54.9V416h-66.4V202.2h63.7v29.2h.9c8.9-16.8 30.6-34.5 62.9-34.5 67.2 0 79.7 44.3 79.7 101.9V416z\"></path>\n\t</svg>\n</a>\n";

var team = function team() {
  var protocol = 0 == window.location.href.indexOf('https://') ? 'https' : 'http';
  var modalEl = document.getElementById('modal-team');
  var modal = new bootstrap.Modal(modalEl, {
    backdrop: true,
    focus: true
  });

  modal._element.addEventListener('hidden.bs.modal', function () {
    var modalEl = jQuery(modal._element);
    modalEl.find('.video-content').html('');
  });

  jQuery('.team-item').on('click', function () {
    var modalEl = jQuery(modal._element);
    var team = jQuery(this);
    var data = team.data();
    var spinner = "<div class=\"spinner-border text-light\" role=\"status\">\n        <span class=\"visually-hidden\">Loading...</span>\n      </div>";
    modalEl.find('.video-content').html(spinner);

    if (data.teamVideo) {
      modalEl.find('.video-content').show();
      jQuery.getJSON(protocol + '://www.vimeo.com/api/oembed.json?url=' + encodeURIComponent(data.teamVideo) + '&width=686&title=0&byline=0&portrait=0&sidedock=0&callback=?', function (data) {
        // $( '#some_video_container' ).html( data.html );
        modalEl.find('.video-content').html(data.html);
      });
    } else {
      modalEl.find('.video-content').hide();
    } // Info


    modalEl.find('.info-content').find('.name').text(data.teamName);
    modalEl.find('.info-content').find('.position').text(data.teamPositionLarge);
    modalEl.find('.info-content').find('.bio').html(team.find('.bio').html()); // Social Empty

    modalEl.find('.social-content').html('');

    if (data.teamTwitter) {
      var aTwitter = teamLinkTwitter;
      aTwitter = aTwitter.replace('#twitterUrl', data.teamTwitter);
      modalEl.find('.social-content').append(aTwitter);
    }

    if (data.teamLinkedin) {
      var aLinkedin = teamLinkLinkedin;
      aLinkedin = aLinkedin.replace('#linkedinUrl', data.teamLinkedin);
      modalEl.find('.social-content').append(aLinkedin);
    } // modalEl
    // 	.find( '.social-content' )
    // 	.find( '.twitter' )
    // 	.attr( 'href', data.teamTwitter )
    // 	.css({ display: data.teamTwitter ? 'flex' : 'none' });
    // modalEl
    // 	.find( '.social-content' )
    // 	.find( '.linkedin' )
    // 	.attr( 'href', data.teamLinkedin )
    // 	.css({ display: data.teamLinkedin ? 'flex' : 'none' });
    // const $parent = $( this ).closest( '.alternative-text-wrapper' );
    // const $alternativeText = $parent.find( '.alternative-text' );
    // $( modal._element ).find( '.dinamic-content' ).html( $alternativeText.html() );


    modal.show();
  });
};

jQuery(function () {
  (function () {
    var wrapper = jQuery('.section-team');

    if (0 == wrapper.length) {
      return null;
    }

    team();
  })();
});
"use strict";

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
var markers = false; // Hero animation

var hero = function hero() {
  var hero = jQuery('.section-hero');

  if (0 == hero.length) {
    return null;
  }

  var title = hero.find('.primary-title h1');
  var title2 = hero.find('.secondary-title h1');
  var bodyHero = hero.find('.body-text-content');
  var arrowDown = hero.find('.arrow-down');
  var tlHero = gsap.timeline();
  tlHero.fromTo(title.toArray(), {
    x: 0,
    y: 0,
    autoAlpha: 0
  }, {
    duration: 0.3,
    x: 0,
    y: 0,
    autoAlpha: 1
  }).fromTo(title2.toArray(), {
    x: 0,
    y: 0,
    autoAlpha: 0
  }, {
    duration: 0.3,
    x: 0,
    y: 0,
    autoAlpha: 1
  }).fromTo(bodyHero.toArray(), {
    x: 0,
    y: 0,
    autoAlpha: 0
  }, {
    duration: 0.5,
    x: 0,
    y: 0,
    autoAlpha: 1
  }).fromTo(arrowDown.get(0), {
    x: 0,
    y: 0,
    autoAlpha: 0
  }, {
    duration: 0.5,
    x: 0,
    y: 0,
    autoAlpha: 1
  }).pause();
  ScrollTrigger.create({
    trigger: hero.get(0),
    once: true,
    onEnter: function onEnter() {
      setTimeout(function () {
        tlHero.play();
      }, 600);
    },
    onEnterBack: function onEnterBack() {
    },
    onLeave: function onLeave() {
    }

  });
};


var tiles = function tiles() {
  var sections = jQuery('.section-tiles-animate');

  if (0 == sections.length) {
    return null;
  }

  jQuery('.section-tiles').each(function () {
    var section = jQuery(this);

    var tiles = section.find('.tiles-gsap').find('.tile');
    var tilesCount = section.find('.tiles-gsap:first-child').find('.tile');
    var bgImage = section.find('.bg-image');
    var title = section.find('.section-caption-title');
    var body = section.find('.section-caption-body');
    var arrow = section.find('.tile-arrow');

    var grid = [6, 6];

    if (18 === tilesCount.length) {
      grid = [6, 3];
    }

    if (42 === tilesCount.length) {
      grid = [7, 6];
    }

    var timelineCaption = gsap.timeline({}).fromTo(title.get(0), {
      x: 0,
      y: 0,
      autoAlpha: 0
    }, {
      duration: 0.3,
      x: 0,
      y: 0,
      autoAlpha: 1
    }).fromTo(body.get(0), {
      x: 0,
      y: 0,
      autoAlpha: 0
    }, {
      duration: 0.3,
      x: 0,
      y: 0,
      autoAlpha: 1
    }).fromTo(arrow.get(0), {
      x: 0,
      y: 0,
      autoAlpha: 0
    }, {
      duration: 0.5,
      x: 0,
      y: 0,
      autoAlpha: 1
    }).pause();

    var timelineTiles = gsap.timeline({}).fromTo(tiles.toArray(), {
      rotationY: 90
    }, {
      rotationY: 0,
      duration: 0.3,
      stagger: {
        grid: grid,
        from: 0,
        amount: 1.1
      }
    }).eventCallback('onComplete', function () {
    }).pause();
    var offsetTime = 0;

    if (1024 <= window.innerWidth) {
      offsetTime = 600;
    }

    var duration = timelineTiles.duration() * 1000 - offsetTime;
    ScrollTrigger.create({
      trigger: section.get(0),
      start: '-50%',
      markers: markers,
      onEnter: function onEnter() {
        timelineTiles.play();
        setTimeout(function () {
          timelineCaption.play();
        }, duration);
      }
    });
  });
};


hero();

tiles(); 
// });
"use strict";

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
var timeline = function timeline() {
  var section = jQuery('.section-timeline');

  if (1 > section.length) {
    return;
  }

  var timeoutActive = null;
  var timeoutInactive = null;
  section.find('.timeline-item').on('mouseover', function () {
    var item = jQuery(this);

    if (item.hasClass('active')) {
      return;
    }

    if (timeoutActive) {
      clearTimeout(timeoutActive);
    }

    if (timeoutInactive) {
      clearTimeout(timeoutInactive);
    }

    section.find('.timeline-item').each(function () {
      var current = jQuery(this);
      current.removeClass('activating');
      current.removeClass('active');
    });
    item.removeClass('deactivating').addClass('activating');
    timeoutActive = setTimeout(function () {
      item.addClass('active').removeClass('activating');
    }, 300);
  });
};

var timelineInline = function timelineInline() {
  var section = jQuery('.section-timeline-inline.large');

  if (1 > section.length) {
    return;
  }

  section.find('.timeline-item-inline').on('click', function () {
    var index = jQuery(this).data().index;
    section.find('.item-description').hide();
    section.find('#item-description-' + index).show();
  });
};

jQuery(function () {
  (function () {
    // timeline
    timeline();

    timelineInline();
  })();
});
"use strict";

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
var initTopCarousels = function initTopCarousels() {
  jQuery('.post-top-carousel ').each(function () {
    var carousel = jQuery(this);
    var wrapper = carousel.closest('.post-top-carousel-wrapper');
    var navigation = wrapper.find('.post-top-carousel-navigation');
    var navigationPrev = navigation.find('.prev');
    var navigationNext = navigation.find('.next');

    function checkIfHasNavigation(slick) {
      if (slick.slideCount > slick.options.slidesToShow) {
        navigationNext.removeClass('disabled');
        navigation.removeClass('d-none');
      } else {
        navigationNext.addClass('disabled');
        navigationPrev.addClass('disabled');
        navigation.addClass('d-none');
      }
    } // Navigation Flow


    function navigationFlow(slick) {
      if (slick.currentSlide >= slick.slideCount - slick.options.slidesToShow) {
        navigationNext.addClass('disabled');
      } else {
        navigationNext.removeClass('disabled');
      }

      if (0 == slick.currentSlide) {
        navigationPrev.addClass('disabled');
      } else {
        navigationPrev.removeClass('disabled');
      }
    }

    carousel.on('init', function (event, slick) {
      checkIfHasNavigation(slick);
      navigationFlow(slick);
    });
    carousel.slick({
      infinite: false,
      arrows: false,
      dots: false,
      autoplay: false,
      speed: 900,
      rows: 0,
      slidesToShow: 1
    });
    carousel.on('afterChange', function (event, slick) {
      navigationFlow(slick);
    }); // Navigation

    navigationPrev.on('click', function (e) {
      e.stopPropagation();
      e.preventDefault();
      carousel.slick('slickPrev');
    });
    navigationNext.on('click', function (e) {
      e.stopPropagation();
      e.preventDefault();
      carousel.slick('slickNext');
    });
  });
};

jQuery(function () {
  (function () {
    var wrapper = jQuery('.section-post-top-carousel');

    if (0 == wrapper.length) {
      return null;
    }

    initTopCarousels();
  })();
});
"use strict";

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
// Animate From
function gsapAnimateFrom(elem, direction) {
  direction = direction || 1;
  var x = 0,
      y = direction * 100;

  if (elem.classList.contains('gs_reveal_fromLeft')) {
    x = -100;
    y = 0;
  } else if (elem.classList.contains('gs_reveal_fromRight')) {
    x = 100;
    y = 0;
  } else if (elem.classList.contains('gs_reveal_fromBottom')) {
    x = 0;
    y = 100;
  }

  elem.style.transform = 'translate(' + x + 'px, ' + y + 'px)';
  elem.style.opacity = '0';
  var data = jQuery(elem).data();
  gsap.fromTo(elem, {
    x: x,
    y: y,
    autoAlpha: 0
  }, {
    delay: data.gsapDelay ? data.gsapDelay : 0,
    duration: 1.25,
    x: 0,
    y: 0,
    autoAlpha: 1,
    ease: 'expo',
    overwrite: 'auto'
  });
} // Hide


function gsapHide(elem) {
  gsap.set(elem, {
    autoAlpha: 0
  });
}

var parallaxEntrance = function parallaxEntrance() {
  gsap.utils.toArray('.gs_reveal').forEach(function (elem) {
    gsapHide(elem);

    var data = jQuery(elem).data();

    if (data.gsapOnce) {
      ScrollTrigger.create({
        trigger: elem,
        once: true,
        onEnter: function onEnter() {
          gsapAnimateFrom(elem);
        }
      });
    } else {
      ScrollTrigger.create({
        trigger: elem,
        once: true,
        onEnter: function onEnter() {
          gsapAnimateFrom(elem);
        },
        onLeaveBack: function onLeaveBack() {// gsapAnimateFrom(elem, -1);
        },
        onLeave: function onLeave() {// gsapHide( elem );
        } // assure that the element is hidden when scrolled into view

      });
    }
  });
};

jQuery(function () {
  (function () {
    parallaxEntrance();
  })();
});
"use strict";

/* eslint-disable no-undef */
jQuery(function () {
  (function () {
    if (0 < jQuery('.section-big-video').length) {
      sectionBigVideo();
      sectionBigVideoReveal();
    }

    if (0 < jQuery('.section-mission').length) {
      sectionMission();
    }

    if (0 < jQuery('.section-approach').length) {
      sectionApproach();
    }

    if (0 < jQuery('.section-core-beliefs').length) {
      sectionCoreBeliefs();
    } // We Focus


    if (jQuery('.section-we-focus').length > 0) {
      sectionWeFocus();
    } // Slide Up


    if (jQuery('.section-slide-up').length > 0) {
      sectionSlideUp();
    } // Quantifiying Impact


    if (jQuery('.section-quantifiying-impact').length > 0) {
      sectionQuantifiyingImpact();
    }

    setTimeout(function () {
      ScrollTrigger.refresh();
    }, 1000);
  })();
});
"use strict";

/* eslint-disable vars-on-top */

/* eslint-disable no-undef */
// Anchor Scroll
Site.anchorScroll = function () {
  if (location.hash) {
    var hashname = location.hash;
    var elem = jQuery(hashname); // console.log( 'elem', elem );

    if (0 < elem.length) {
      if ('top' === hashname) {
        jQuery('body, html').animate({
          scrollTop: 0
        }, 200);
      } else {
        // console.log("elem", elem);
        Site.scrollTo(hashname);
      }
    }
  }
};

Site.anchorClick = function () {
  jQuery('a.anchor-link').on('click', function (e) {
    var href = jQuery(this).attr('href');
    var elem = jQuery(href);

    if (0 < elem.length) {
      e.preventDefault();
      e.stopPropagation();
      Site.scrollToEl(href, 0);
    }
  });
};

Site.submenuAnchorsWatch = function () {
  // Cache selectors
  var topMenu = jQuery('header'),
      topMenuHeight = topMenu.outerHeight() + 15,
      // All list items
  menuItems = topMenu.find('.subheader-nav a'),
      // Anchors corresponding to menu items
  scrollItems = menuItems.map(function () {
    var item = jQuery(jQuery(this).attr('href'));

    if (item.length) {
      return item;
    }
  }); // Bind to scroll

  jQuery(window).scroll(function () {
    // Get container scroll position
    var fromTop = jQuery(this).scrollTop() + topMenuHeight; // Get id of current scroll item

    var cur = scrollItems.map(function () {
      if (jQuery(this).offset().top < fromTop) {
        return this;
      }
    });

    if (cur.length < 1) {
      return;
    } // Get the id of the current element


    cur = cur[cur.length - 1];
    var id = cur && cur.length ? cur[0].id : ''; // Set/remove active class

    menuItems.parent().removeClass('active').end().filter("[href='#" + id + "']").parent().addClass('active');
  });
};

jQuery(function () {
  (function () {
    Site.anchorScroll();
    Site.anchorClick();
    Site.submenuAnchorsWatch(); // Pagination Query Params

    if ('undefined' !== typeof paginationElID) {
      Site.scrollTo(paginationElID);
    }
  })();
});